Learn R Programming

turfR (version 0.8-4)

turf.args: Arguments used in TURF Analysis

Description

INTERNAL: A list of named arguments that can be passed into turf and turf.combos to control the behavior and output of the TURF algorithm.

Usage

turf.args(depth=1L, keep=0, mc=FALSE, nsims=10000, psims=NULL, sort="d")

Arguments

depth
Scalar indicating depth of reach, see Markowitz (2005). depth is an integer, greater than or equal to 1; non-integer values are coerced using floor(depth).
keep
Scalar indicating the number of combinations of each size to keep in the output object generated by turf. keep is an integer, greater than or equal to zero; non-integer values are coerced using floor(keep). If
mc
Logical indicating whether or not Monte Carlo simulated subsets of combinations should be substituted for all possible combinations of n choose k or user-specified combinations. When TRUE, subsets are generated using the method desc
nsims
Scalar indicating the number of combination sets of a given size to generate when mc == TRUE. nsims is an integer, greater than or equal to 1; non-integer values are coerced using floor(nsims). This argument is
psims
Vector of length n indicating the probabilities of sampling each item into a combination set when mc == TRUE. Probabilities need not sum to 1 (see sample for additional details). All values must be greater than or
sort
Character indicating sort order of TURF output: "d" (default) causes combinations to be sorted in descending order of reach, then frequency; "a" causes combinations to be sorted in ascending order of reach, then frequency; "n" leaves combinations

Value

  • A list consisting of the named arguments.

Details

Defaults set by this function may be modified by specifying any of the arguments as name-value pairs in place of the (...) argument when calling turf or turf.combos. It is never necessary to call turf.args directly.

References

Adler, T.J., Smith, C. & Dumont, J. 2010. Optimizing product portfolios using discrete choice modeling and TURF. In: S. Hess, A. Daly (Eds), Choice modeling: the state-of-the-art and the state-of-practice; proceedings from the Inaugural International Choice Modeling Conference. Emerald Publishing Group Ltd., pp. 485-497. Krieger, A.M. & Green, P.E. 2000. Turf revisited: Enhancements to toal unduplicated reach and frequency analysis. Marketing Research, 12, 30-36. Markowitz, L. 2005. Going beyond TURF to complement and extend existing product lines. Ipsos-Insight, November 2005. Miaoulis, G., Free, V. & Parsons, H. 1990. TURF: A new planning approach for product line extensions. Marketing Research, March, pp. 28-40.

Examples

Run this code
##INTERNAL USE ONLY

Run the code above in your browser using DataLab