Arguments
depth
Scalar indicating depth of reach, see Markowitz (2005). depth is an integer, greater than or equal to 1;
non-integer values are coerced using floor(depth).
keep
Scalar indicating the number of combinations of each size to keep in the output object generated by turf.
keep is an integer, greater than or equal to zero; non-integer values are coerced using floor(keep). If
mc
Logical indicating whether or not Monte Carlo simulated subsets of combinations should be substituted for all possible
combinations of n choose k or user-specified combinations. When TRUE, subsets are generated using the method desc
nsims
Scalar indicating the number of combination sets of a given size to generate when mc == TRUE. nsims is an
integer, greater than or equal to 1; non-integer values are coerced using floor(nsims). This argument is
psims
Vector of length n indicating the probabilities of sampling each item into a combination set when mc ==
TRUE. Probabilities need not sum to 1 (see sample for additional details). All values must be greater than or
sort
Character indicating sort order of TURF output: "d" (default) causes combinations to be sorted in descending order of
reach, then frequency; "a" causes combinations to be sorted in ascending order of reach, then frequency; "n" leaves combinations